@@ -20,7 +20,7 @@ class MirtoRobot:
         """
         self.motors[0].set_motor(speed1)
         self.motors[1].set_motor(speed2)
-        sys.stdout.write("DEBUG: setting motors to {}, {}\n".format(speed1, speed2))
+        # sys.stdout.write("DEBUG: setting motors to {}, {}\n".format(speed1, speed2))
 
     def stop_motors(self):
         """
@@ -72,7 +72,7 @@ class MirtoRobot:
         :return:
         """
         self.motors[0].reset_count()
-        sys.stdout.write("Reset encoders\n")
+        # sys.stdout.write("Reset encoders\n")
 
     def get_all_ir_values(self, sensor_order=None):
         """
@@ -96,7 +96,7 @@ class MirtoRobot:
         :param duration: int
         :return: if error return -1
         """
-        if motor_ID in [0, 1]:
+        if motor_id in [0, 1]:
             self.motors[motor_id].set_motor_rpm(rpm, duration)
         else:
             return -1
@@ -130,9 +130,9 @@ class MirtoRobot:
         """
         self.lcd[0].clear_lcd()
 
-    def rotate_robot_angle(self, angle, speed):
+    def rotate_robot_angle(self, speed, angle):
         """
-        This function takes in a angle and a speed
+        This function takes angle and speed and is rotating this robot for given angle.
         :param angle: int
         :param speed: int
         :return: None
@@ -152,8 +152,8 @@ class MirtoRobot:
 
     def set_robot_speed_cm(self, speed, duration):
         """
-        This function takes in a angle and a speed
-        :param angle: int
+        This function takes distance in cm and time in which is suppose to travel this distance.
+        :param duration:
         :param speed: int
         :return: None
         """
